Struct mpl_candy_guard::guards::AddressGate
source · pub struct AddressGate {
pub address: Pubkey,
}Expand description
Guard that restricts access to a specific address.
Fields
address: PubkeyTrait Implementations
sourceimpl BorshDeserialize for AddressGatewhere
Pubkey: BorshDeserialize,
impl BorshDeserialize for AddressGatewhere
Pubkey: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
sourceimpl BorshSerialize for AddressGatewhere
Pubkey: BorshSerialize,
impl BorshSerialize for AddressGatewhere
Pubkey: BorshSerialize,
sourceimpl Clone for AddressGate
impl Clone for AddressGate
sourcefn clone(&self) -> AddressGate
fn clone(&self) -> AddressGate
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Condition for AddressGate
impl Condition for AddressGate
sourcefn validate<'info>(
&self,
ctx: &mut EvaluationContext<'_, '_, '_>,
_guard_set: &GuardSet,
_mint_args: &[u8]
) -> Result<()>
fn validate<'info>( &self, ctx: &mut EvaluationContext<'_, '_, '_>, _guard_set: &GuardSet, _mint_args: &[u8] ) -> Result<()>
Validate the condition of the guard. When the guard condition is
not satisfied, it will return an error. Read more
sourcefn pre_actions(
&self,
_ctx: &mut EvaluationContext<'_, '_, '_>,
_guard_set: &GuardSet,
_mint_args: &[u8]
) -> Result<()>
fn pre_actions( &self, _ctx: &mut EvaluationContext<'_, '_, '_>, _guard_set: &GuardSet, _mint_args: &[u8] ) -> Result<()>
Perform the action associated with the guard before the CPI
mint instruction. Read moresourcefn post_actions(
&self,
_ctx: &mut EvaluationContext<'_, '_, '_>,
_guard_set: &GuardSet,
_mint_args: &[u8]
) -> Result<()>
fn post_actions( &self, _ctx: &mut EvaluationContext<'_, '_, '_>, _guard_set: &GuardSet, _mint_args: &[u8] ) -> Result<()>
Perform the action associated with the guard after the CPI
mint instruction. Read moresourceimpl Debug for AddressGate
impl Debug for AddressGate
sourceimpl Guard for AddressGate
impl Guard for AddressGate
sourcefn instruction<'info>(
_ctx: &Context<'_, '_, '_, 'info, Route<'info>>,
_route_context: RouteContext<'info>,
_data: Vec<u8>
) -> Result<()>
fn instruction<'info>( _ctx: &Context<'_, '_, '_, 'info, Route<'info>>, _route_context: RouteContext<'info>, _data: Vec<u8> ) -> Result<()>
Executes an instruction. This function is called from the
route instruction
handler.sourcefn is_enabled(features: u64) -> bool
fn is_enabled(features: u64) -> bool
Returns whether the guards is enabled or not on the specified features.
sourcefn save(&self, data: &mut [u8], offset: usize) -> Result<()>
fn save(&self, data: &mut [u8], offset: usize) -> Result<()>
Serializes the guard into the specified data array.