pub struct ProgramGate {
pub additional: Vec<Pubkey>,
}Expand description
Guard that restricts the programs that can be in a mint transaction. The guard allows the necessary programs for the mint and any other program specified in the configuration.
Fields
additional: Vec<Pubkey>Trait Implementations
Sourceimpl BorshDeserialize for ProgramGate
impl BorshDeserialize for ProgramGate
Sourceimpl BorshSerialize for ProgramGate
impl BorshSerialize for ProgramGate
Sourceimpl Clone for ProgramGate
impl Clone for ProgramGate
Sourcefn clone(&self) -> ProgramGate
fn clone(&self) -> ProgramGate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Condition for ProgramGate
impl Condition for ProgramGate
Sourcefn validate<'info>(
&self,
ctx: &mut EvaluationContext<'_, '_, '_>,
_guard_set: &GuardSet,
_mint_args: &[u8],
) -> Result<()>
fn validate<'info>( &self, ctx: &mut EvaluationContext<'_, '_, '_>, _guard_set: &GuardSet, _mint_args: &[u8], ) -> Result<()>
Validate the condition of the guard. When the guard condition is
not satisfied, it will return an error. Read more
Sourcefn pre_actions(
&self,
_ctx: &mut EvaluationContext<'_, '_, '_>,
_guard_set: &GuardSet,
_mint_args: &[u8],
) -> Result<()>
fn pre_actions( &self, _ctx: &mut EvaluationContext<'_, '_, '_>, _guard_set: &GuardSet, _mint_args: &[u8], ) -> Result<()>
Perform the action associated with the guard before the CPI
mint instruction. Read moreSourcefn post_actions(
&self,
_ctx: &mut EvaluationContext<'_, '_, '_>,
_guard_set: &GuardSet,
_mint_args: &[u8],
) -> Result<()>
fn post_actions( &self, _ctx: &mut EvaluationContext<'_, '_, '_>, _guard_set: &GuardSet, _mint_args: &[u8], ) -> Result<()>
Perform the action associated with the guard after the CPI
mint instruction. Read moreSourceimpl Debug for ProgramGate
impl Debug for ProgramGate
Sourceimpl Guard for ProgramGate
impl Guard for ProgramGate
Sourcefn verify(data: &CandyGuardData) -> Result<()>
fn verify(data: &CandyGuardData) -> Result<()>
Verifies that the candy guard configuration is valid according to the rules
of the guard.
Sourcefn instruction<'info>(
_ctx: &Context<'_, '_, '_, 'info, Route<'info>>,
_route_context: RouteContext<'info>,
_data: Vec<u8>,
) -> Result<()>
fn instruction<'info>( _ctx: &Context<'_, '_, '_, 'info, Route<'info>>, _route_context: RouteContext<'info>, _data: Vec<u8>, ) -> Result<()>
Executes an instruction. This function is called from the
route instruction
handler.Sourcefn is_enabled(features: u64) -> bool
fn is_enabled(features: u64) -> bool
Returns whether the guards is enabled or not on the specified features.